==> puppet-7.12.0-1-any.pkg.tar.xz: opt/puppetlabs/puppet/vendor_modules/yumrepo_core/CHANGELOG.md <==
# Change log

All notable changes to this project will be documented in this file. The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/) and this project adheres to [Semantic Versioning](http://semver.org).

## [1.0.7](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.7) (2020-04-13)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.6...1.0.7)

### Added

- \(MODULES-10617\) Add property module\_hotfixes [\#28](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/28) ([seriv](https://github.com/seriv))

## [1.0.6](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.6) (2019-12-19)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.5...1.0.6)

### Fixed

- \(MODULES-10357\) Fix `proxy =\> absent` [\#24](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/24) ([alexjfisher](https://github.com/alexjfisher))

## [1.0.5](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.5) (2019-12-18)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.4...1.0.5)

### Fixed

- \(MODULES-10246\) Proxy settings allow empty string [\#22](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/22) ([Dorin-Pleava](https://github.com/Dorin-Pleava))

## [1.0.4](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.4) (2019-10-31)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.3...1.0.4)

### Added

- \(PUP-10028\) Add minrate to yumrepo [\#18](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/18) ([jtappa](https://github.com/jtappa))

## [1.0.3](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.3) (2019-01-11)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.2...1.0.3)

### Added

- \(maint\) add LICENSE file [\#13](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/13) ([melissa](https://github.com/melissa))

## [1.0.2](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.2) (2018-11-29)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.1...1.0.2)

### Added

- \(L10n\) Update Japanese translations [\#9](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/9) ([melissa](https://github.com/melissa))

### Fixed

- \(MODULES-8114\) Use old way of defining sensitive params [\#6](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/6) ([melissa](https://github.com/melissa))

## [1.0.1](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.1) (2018-08-17)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.0...1.0.1)

## [1.0.0](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.0) (2018-07-09)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/5c905b7ed57e5c60b4469050b7306a9c9b78e304...1.0.0)

### Added

- Extract yumrepo type and provider from puppet [\#1](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/1) ([joshcooper](https://github.com/joshcooper))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*

==> puppet-7.16.0-1-any.pkg.tar.xz: opt/puppetlabs/puppet/vendor_modules/yumrepo_core/CHANGELOG.md <==
# Change log

All notable changes to this project will be documented in this file. The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/) and this project adheres to [Semantic Versioning](http://semver.org).

## [v1.1.0](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/v1.1.0) (2021-10-04)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.7...v1.1.0)

### Added

- \(MODULES-11167\)\(MODULES-11191\) Add RockyLinux && AlmaLinux to yumrepo\_core metadata [\#39](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/39) ([BobosilaVictor](https://github.com/BobosilaVictor))

## [1.0.7](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.7) (2020-04-13)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.6...1.0.7)

### Added

- \(MODULES-10617\) Add property module\_hotfixes [\#28](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/28) ([seriv](https://github.com/seriv))

## [1.0.6](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.6) (2019-12-19)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.5...1.0.6)

### Fixed

- \(MODULES-10357\) Fix `proxy => absent` [\#24](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/24) ([alexjfisher](https://github.com/alexjfisher))

## [1.0.5](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.5) (2019-12-18)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.4...1.0.5)

### Fixed

- \(MODULES-10246\) Proxy settings allow empty string [\#22](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/22) ([Dorin-Pleava](https://github.com/Dorin-Pleava))

## [1.0.4](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.4) (2019-10-31)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.3...1.0.4)

### Added

- \(PUP-10028\) Add minrate to yumrepo [\#18](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/18) ([jtappa](https://github.com/jtappa))

## [1.0.3](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.3) (2019-01-11)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.2...1.0.3)

### Added

- \(maint\) add LICENSE file [\#13](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/13) ([melissa](https://github.com/melissa))

## [1.0.2](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.2) (2018-11-29)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.1...1.0.2)

### Added

- \(L10n\) Update Japanese translations [\#9](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/9) ([melissa](https://github.com/melissa))

### Fixed

- \(MODULES-8114\) Use old way of defining sensitive params [\#6](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/6) ([melissa](https://github.com/melissa))

## [1.0.1](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.1) (2018-08-17)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/1.0.0...1.0.1)

## [1.0.0](https://github.com/puppetlabs/puppetlabs-yumrepo_core/tree/1.0.0) (2018-07-09)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-yumrepo_core/compare/5c905b7ed57e5c60b4469050b7306a9c9b78e304...1.0.0)

### Added

- Extract yumrepo type and provider from puppet [\#1](https://github.com/puppetlabs/puppetlabs-yumrepo_core/pull/1) ([joshcooper](https://github.com/joshcooper))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
